/*
 * Copyright (c) 2020 RTSoft. All rights reserved.
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Licensed under the Apache License, Version 2.0 (the License); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/*
 * slaves.c
 */

/*
 * Slaves output info example
 */
#include "fttypes.h"
#include "ftalloc.h"
#include "ftslave.h"

#include <stdio.h>
#include <ctype.h>

static void *txt, *txt2;

int main(int argc, char **argv)
{
	(void)argc;
    txt = ftop_alloc_txt("auto", 65000);

    if (txt == NULL) {
        fprintf(stderr, "Can't conect 'auto'\n");
        return 1;
    }

    int n = ftop_get_slaves_number(txt);

    printf("Number of slaves is %d\n", n);

    printf("Information about TXT2 controllers\n");

    int i;
    for (i = 0; i <= n; i++) {
    	printf("------- Controller %d -----------------------\n", i);
    	printf("Controller name : %s\n", ftop_get_txt_name(txt, i));
    	printf("Controller SN   : %s\n", ftop_get_txt_SN(txt, i));
    	printf("Controller UID  : 0x%8.8x\n", ftop_get_txt_uid(txt, i));
    }

	if (argv[1] == NULL)
		return 0;

	int num;
	if (argv[1][0] == '0') {
		sscanf(argv[1], "%i", &num);
		txt2 = ftop_get_slave_by_uid(txt, num);
	} else if (isdigit(argv[1][0])) {
		sscanf(argv[1], "%i", &num);
		txt2 = ftop_get_slave_by_order(txt, num);
	} else {
		txt2 = ftop_get_slave_by_name(txt, argv[1]);
	}

	if (txt2 == NULL) {
		printf("Can't use '%s' parameter for allocation\n", argv[1]);
		return 1;
	}

    printf("------- Controller %s -----------------------\n", argv[1]);

    /* Check new TXT object */
	printf("Controller name     : %s\n", ftop_get_name(txt2));
	printf("Controller Version  : %d\n", ftop_get_version(txt2));
	printf("Controller Firmware : 0x%8.8x\n", ftop_get_firmware(txt2));

    return 0;
}
