/*
 * Copyright (c) 2020 RTSoft. All rights reserved.
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Licensed under the Apache License, Version 2.0 (the License); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/**
 * @file ftcalib.h
 * @brief Calibration structures for ftcalib utility
 */

#ifndef FTINC_FTCALIB_H_
#define FTINC_FTCALIB_H_

#include <stdint.h>

#define FTCALIB "FTCALIB"	/*!< Magic string for calibration structure in memory or file */
#define FTCALIB_VER 4		/*!< Current calibration structure version */

/**
 * Calibration values per analog channel
 */
struct ftcalib_group {
	uint32_t div1; /*!< mv raw value r1 mode */
	uint32_t val1; /*!< mv real value        */
	uint32_t div2; /*!< mv raw value r2 mode */
	uint32_t val2; /*!< mv real value        */
};

/**
 * Structure for calibration rev1
 */
struct ftcalib1 {
	char ftmark[8];   /*!< "ftcalib" */
	uint32_t mmark;   /*!< Must be zero in file */
	uint32_t version; /*!< Must be 1 */
	uint32_t uid;	  /*!< board uid value */
	uint32_t adcs;    /*!< ADC sampling time */
	uint32_t adct1;   /*!< ADC R1 time */
	uint32_t adct2;   /*!< ADC R2 time */
	uint32_t adcd1;   /*!< ADC R1 divider */
	uint32_t adcd2;   /*!< ADC R2 divider */
	uint32_t adcr1;   /*!< ADC R1 coefficient */
	uint32_t adcr2;   /*!< ADC R2 coefficient */
};

/**
 * Structure for calibration rev2
 */
struct ftcalib2 {
	char ftmark[8];   /*!< "ftcalib" */
	uint32_t mmark;   /*!< Must be zero in file */
	uint32_t version; /*!< Must be 2 */
	uint32_t uid;	  /*!< board uid value */
	uint32_t adcs;    /*!< ADC sampling time */
	uint32_t adct1;   /*!< ADC R1 time */
	uint32_t adct2;   /*!< ADC R2 time */
	struct ftcalib_group channel[8]; /*!< calibration values per analog channels */
};

/**
 * Structure for calibration rev3
 */
struct ftcalib3 {
	char ftmark[8];   /*!< "ftcalib" */
	uint32_t mmark;   /*!< Must be zero in file */
	uint32_t version; /*!< Must be 3 */
	uint32_t uid;	  /*!< board uid value */
	uint32_t adcs;    /*!< ADC sampling time */
	uint32_t adct1;   /*!< ADC R1 time */
	uint32_t adct2;   /*!< ADC R2 time */
	struct ftcalib_group channel[8]; /*!< calibration values per analog channels */
	uint32_t u0t;     /*!< US 0 time */
	uint32_t u1t;     /*!< US 1 time */
	uint32_t ut;      /*!< US timeout */
	uint32_t dt;	  /*!< D  timeout */
};

/**
 * Structure for calibration
 */
struct ftcalib {
	char ftmark[8];   /*!< "ftcalib" */
	uint32_t mmark;   /*!< Must be zero in file */
	uint32_t version; /*!< Must be 4 */
	uint32_t uid;     /*!< board uid value */
	uint32_t adcs;    /*!< ADC sampling time */
	uint32_t adct1;   /*!< ADC R1 time */
	uint32_t adct2;   /*!< ADC R2 time */
	struct ftcalib_group channel[8]; /*!< calibration values per analog channels */
	uint32_t u0t;     /*!< US 0 time */
	uint32_t u1t;     /*!< US 1 time */
	uint32_t ut;      /*!< US timeout */
	uint32_t dt;	  /*!< D  timeout */
	uint16_t tm[5];   /*!< time marks for TTCAN */
	uint16_t rt;	  /*!< responce time */
	uint32_t cnr;	  /*!< CAN Numerator */
	uint32_t dnr;	  /*!< CAN Denominator */
	uint32_t ct;	  /*!< CAN Tx timeout */
};

#endif /* FTINC_FTCALIB_H_ */
