/*
 * Copyright (c) 2020 RTSoft. All rights reserved.
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Licensed under the Apache License, Version 2.0 (the License); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/**
 * @file ftsrc/ftcalib.c
 * @brief Default initialization for calibration values
 */

#include "ftcalib.h"
#include "main.h" /* For TXT2_BOARD_REVISION */

/* External variables */

struct ftcalib ftcalib = {
		.ftmark = FTCALIB,
		.version = FTCALIB_VER,
		.uid = 0,
		.adcs = 6,
		.adct1 = 100000, /* ns */
		.adct2 = 100000, /* ns */
		.channel = {{
#if TXT2_BOARD_REVISION == 1
				.div1 = 2967,
				.div2 = 1843,
				.val1 = 4650,
				.val2 = 4620,
#else
				.div1 = 4036,
				.div2 = 2717,
				.val1 = 4750,
				.val2 = 4710,
#endif
		},},
		.u0t = 78200,
		.u1t = 800,
		.ut = 800000,
		.dt = 25000, /* 25 mks delay for digital input */
		.tm  = {160, 1280, 1400, 2000, 12800}, /* TODO: reduce */
		.rt = 5, /* ms no reason check it very fast */
		.cnr = 0x1ffff,
		.dnr = 8192,
		.ct = 30, /* ms */
};
