/*
 * Copyright (c) 2020 RTSoft. All rights reserved.
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Licensed under the Apache License, Version 2.0 (the License); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/**
 * @defgroup Firmware_Implementation_Includes
 * @{
 */

/**
 * @file ExtEngine.h
 * @brief External Communication Engine global variables and procedures
 */

#ifndef SRC_EXTENGINE_H_
#define SRC_EXTENGINE_H_

/**
 * @addtogroup External_Engine
 * @{
 */

#include "ftext.h"

/* External variables */

int masterSilentMode;		/*!< Second master silent mode */
uint32_t masterSilentTick;	/*!< Start tick to stop any CAN activity for second master */
uint32_t master_tick;		/*!< Start tick to produce master notification packet */

/* Exported functions */

/**
 * @brief Prepare new package for master (discovery, info, values)
 * @param [in] ecommand buffer for new package
 */
void ProcessSlaveTxPacket(TXT2_ext_command *ecommand);

/**
 * @brief Process new package from master (set addr, config, op)
 * @param [in] CanRxData buffer with new package
 */
void ProcessPacketFromMaster(void *CanRxData);

/**
 * @brief Process discovery package from slave
 * @param [in] CanRxData buffer with new package
 */
void ProcessDiscoveryFromSlave(void *CanRxData);

/**
 * @brief Process package from slave or another master (master/slave info, values)
 * @param [in] CanRxHeader can header
 * @param [in] CanRxData buffer with new package
 */
void ProcessPacketFromSlave(FDCAN_RxHeaderTypeDef *CanRxHeader, void *CanRxData);

/**
 * @brief Select type and send new frame
 * @param [in] ecommand command buffer
 *
 * return can do something
 */
int ProcessMasterTxPacket(TXT2_ext_command *ecommand);

/**
 * @brief Send new config from master to slave
 * @param nslave slave controller number
 * @param ecommand command buffer
 */
void SendConfigPacket(int nslave, TXT2_ext_command *ecommand);

/**
 * @brief Send new operation for O1-O8 from master to slave
 * @param txt slave controller
 * @param ecommand command buffer
 */
void SendOpPacket(struct ft_shm_txt *txt, TXT2_ext_command *ecommand);

/**
 * @brief Send CAN ID from master to slave
 * @param txt slave controller
 * @param ecommand command buffer
 */
void SendAddrPacket(struct ft_shm_txt *txt, TXT2_ext_command *ecommand);

#endif /* SRC_EXTENGINE_H_ */

/** @} */

/** @} */
